@@ -34,6 +34,10 @@ function _aws_cdk_aws_cloudfront_origins_OriginGroupProps(p) {
 }
 function _aws_cdk_aws_cloudfront_origins_OriginGroup(p) {
 }
+function _aws_cdk_aws_cloudfront_origins_RestApiOriginProps(p) {
+}
+function _aws_cdk_aws_cloudfront_origins_RestApiOrigin(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -70,4 +74,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_cloudfront_origins_HttpOriginProps, _aws_cdk_aws_cloudfront_origins_HttpOrigin, _aws_cdk_aws_cloudfront_origins_LoadBalancerV2OriginProps, _aws_cdk_aws_cloudfront_origins_LoadBalancerV2Origin, _aws_cdk_aws_cloudfront_origins_S3OriginProps, _aws_cdk_aws_cloudfront_origins_S3Origin, _aws_cdk_aws_cloudfront_origins_OriginGroupProps, _aws_cdk_aws_cloudfront_origins_OriginGroup };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_cloudfront_origins_HttpOriginProps, _aws_cdk_aws_cloudfront_origins_HttpOrigin, _aws_cdk_aws_cloudfront_origins_LoadBalancerV2OriginProps, _aws_cdk_aws_cloudfront_origins_LoadBalancerV2Origin, _aws_cdk_aws_cloudfront_origins_S3OriginProps, _aws_cdk_aws_cloudfront_origins_S3Origin, _aws_cdk_aws_cloudfront_origins_OriginGroupProps, _aws_cdk_aws_cloudfront_origins_OriginGroup, _aws_cdk_aws_cloudfront_origins_RestApiOriginProps, _aws_cdk_aws_cloudfront_origins_RestApiOrigin };
